Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(683)

Unified Diff: chrome/browser/idle.h

Issue 7864022: Fixing the bug, that caused UI to hang after unsupported device was inserted. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: style fixes Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/idle.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/idle.h
diff --git a/chrome/browser/idle.h b/chrome/browser/idle.h
index 05b5066351400cdf28dcbb771294f9317c44953e..573b537f04401c465fc1e33ad6e0e8bd394cda27 100644
--- a/chrome/browser/idle.h
+++ b/chrome/browser/idle.h
@@ -27,7 +27,7 @@ typedef base::Callback<void(IdleState)> IdleCallback;
// Calculate the Idle state and notify the callback.
void CalculateIdleState(unsigned int idle_threshold, IdleCallback notify);
-// Calculate the Idle state synchronously and return the state.
-IdleState CalculateIdleStateSync(unsigned int idle_threshold);
+// Checks synchronously if Idle state is IDLE_STATE_LOCKED.
+bool CheckIdleStateIsLocked();
#endif // CHROME_BROWSER_IDLE_H_
« no previous file with comments | « no previous file | chrome/browser/idle.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698